Reporting and Configuration Class Reference
===========================================

.. automodule:: steelscript.appresponse.core.appresponse

.. currentmodule:: steelscript.appresponse.core.appresponse

:py:class:`AppResponse` Objects
-------------------------------

.. autoclass:: AppResponse
    :members:

    .. automethod:: __init__

.. automodule:: steelscript.appresponse.core.reports

.. currentmodule:: steelscript.appresponse.core.reports

Reporting Objects
-----------------

.. autoclass:: DataDef
    :members:

    .. automethod:: __init__


.. autoclass:: Report
    :members:

    .. automethod:: __init__

